rw: Compute rank-width and rank-decompositions
==============================================

Description
-----------

rw is a program that calculates rank-width and rank-decompositions.

https://sourceforge.net/projects/rankwidth/

License
-------

GPL version 2 or later


Upstream Contact
----------------

Philipp Klaus Krause (philipp@informatik.uni-frankfurt.de)
